@@ -1,11 +1,11 @@
 /****************************************************************************
-** $Id: qt/qmap.h   3.1.2   edited Feb 17 06:11 $
+** $Id: qt/qmap.h   3.3.0   edited May 27 2003 $
 **
 ** Definition of QMap class
 **
 ** Created : 990406
 **
-** Copyright (C) 1992-2002 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2003 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the tools module of the Qt GUI Toolkit.
 **
@@ -323,6 +323,7 @@ Q_INLINE_TEMPLATES int QMapConstIterator<K,T>::dec()
     return 0;
 }
 
+// ### 4.0: rename to something without Private in it. Not really internal.
 class Q_EXPORT QMapPrivateBase : public QShared
 {
 public:
@@ -627,18 +628,10 @@ public:
     }
 
 #ifndef QT_NO_STL
-#  ifdef Q_CC_HPACC    // HP-UX aCC does require typename in some place
-#    undef Q_TYPENAME  // but not accept them at others.
-#    define Q_TYPENAME // also doesn't like re-defines ...
-#  endif
-    QMap( const Q_TYPENAME std::map<Key,T>& m )
+    QMap( const std::map<Key,T>& m )
     {
 	sh = new QMapPrivate<Key,T>;
-#if defined(Q_OS_WIN32)
-	std::map<Key,T>::const_iterator it = m.begin();
-#else
-	QMapConstIterator<Key,T> it = m.begin();
-#endif
+	Q_TYPENAME std::map<Key,T>::const_iterator it = m.begin();
 	for ( ; it != m.end(); ++it ) {
 	    value_type p( (*it).first, (*it).second );
 	    insert( p );
@@ -652,30 +645,25 @@ public:
     }
     QMap<Key,T>& operator= ( const QMap<Key,T>& m );
 #ifndef QT_NO_STL
-    QMap<Key,T>& operator= ( const Q_TYPENAME std::map<Key,T>& m )
+    QMap<Key,T>& operator= ( const std::map<Key,T>& m )
     {
 	clear();
-#if defined(Q_OS_WIN32)
-	std::map<Key,T>::const_iterator it = m.begin();
-#else
-	QMapConstIterator<Key,T> it = m.begin();
-#endif
+	Q_TYPENAME std::map<Key,T>::const_iterator it = m.begin();
 	for ( ; it != m.end(); ++it ) {
 	    value_type p( (*it).first, (*it).second );
 	    insert( p );
 	}
 	return *this;
     }
-#  ifdef Q_CC_HPACC    // undo the HP-UX aCC hackery done above
-#    undef Q_TYPENAME 
-#    define Q_TYPENAME typename
-#  endif
 #endif
 
     iterator begin() { detach(); return sh->begin(); }
     iterator end() { detach(); return sh->end(); }
     const_iterator begin() const { return ((const Priv*)sh)->begin(); }
     const_iterator end() const { return ((const Priv*)sh)->end(); }
+    const_iterator constBegin() const { return begin(); }
+    const_iterator constEnd() const { return end(); }
+
     iterator replace( const Key& k, const T& v )
     {
 	remove( k );
@@ -740,7 +728,7 @@ public:
 #if defined(Q_FULL_TEMPLATE_INSTANTIATION)
     bool operator==( const QMap<Key,T>& ) const { return FALSE; }
 #ifndef QT_NO_STL
-    bool operator==( const Q_TYPENAME std::map<Key,T>& ) const { return FALSE; }
+    bool operator==( const std::map<Key,T>& ) const { return FALSE; }
 #endif
 #endif
 
@@ -880,8 +868,6 @@ Q_INLINE_TEMPLATES QDataStream& operator<<( QDataStream& s, const QMap<Key,T>& m
 }
 #endif
 
-#ifdef QT_QWINEXPORT
 #define Q_DEFINED_QMAP
 #include "qwinexport.h"
-#endif /* QT_QWINEXPORT */
 #endif // QMAP_H
