@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qpainter.h   3.1.2   edited Jan 29 04:57 $
+** $Id: qt/qpainter.h   3.3.0   edited Nov 12 13:57 $
 **
 ** Definition of QPainter class
 **
@@ -54,6 +54,7 @@ class QGfx;
 class QTextCodec;
 class QTextParag;
 class QPaintDevice;
+class QTextItem;
 #if defined( Q_WS_MAC )
 class QMacSavedPortInfo;
 #endif
@@ -79,6 +80,7 @@ public:
 #endif
 
     static void redirect( QPaintDevice *pdev, QPaintDevice *replacement );
+    static QPaintDevice *redirect( QPaintDevice *pdev );
 
     bool	isActive() const;
 
@@ -259,9 +261,8 @@ public:
 			  const QString&, int len = -1, QRect *br=0,
 			  QTextParag **intern=0 );
 
-    //#####    void	drawText( const QPoint &, const QString &, int flags, int rotation = 0);
-
-  // Text drawing functions
+    void drawTextItem( int x, int y, const QTextItem &ti, int textflags = 0 );
+    void drawTextItem( const QPoint& p, const QTextItem &ti, int textflags = 0 );
 
     QRect	boundingRect( int x, int y, int w, int h, int flags,
 			      const QString&, int len = -1, QTextParag **intern=0 );
@@ -378,11 +379,17 @@ private:
 
 protected:
 #ifdef Q_OS_TEMP
-	QPoint	internalCurrentPos;
+    QPoint	internalCurrentPos;
+    uint	old_pix;			// ### All win platforms in 4.0
 #endif
 #if defined(Q_WS_WIN)
+    friend class QFontEngineWin;
+    friend class QFontEngineBox;
     QT_WIN_PAINTER_MEMBERS
 #elif defined(Q_WS_X11)
+    friend class QFontEngineXLFD;
+    friend class QFontEngineXft;
+    friend class QFontEngineBox;
     Display    *dpy;				// current display
     int		scrn;				// current screen
     Qt::HANDLE	hd;				// handle to drawable
@@ -393,16 +400,24 @@ protected:
     uint	clip_serial;			// clipping serial number
 #elif defined(Q_WS_MAC)
     Qt::HANDLE	hd;				// handle to drawable
-    void initPaintDevice(bool force=FALSE);
+    void initPaintDevice(bool force=FALSE, QPoint *off=NULL, QRegion *rgn=NULL);
+    friend const QRegion &qt_mac_update_painter(QPainter *, bool);
+    friend class QFontEngineMac;
+    friend class QMacPainter;
 #elif defined(Q_WS_QWS)
+    friend class QFontEngine;
     QGfx * gfx;
+    friend void qwsUpdateActivePainters();
 #endif
     friend class QFontMetrics;
     friend class QFontInfo;
+    friend class QTextLayout;
     friend void qt_format_text( const QFont &, const QRect &r,
 		     int tf, const QString& str, int len, QRect *brect,
 		     int tabstops, int* tabarray, int tabarraylen,
 		     QTextParag **internal, QPainter* painter );
+    friend void qt_draw_background( QPainter *p, int x, int y, int w,  int h );
+    friend void qt_draw_transformed_rect( QPainter *p,  int x, int y, int w,  int h, bool fill );
     friend class QPrinter;
 
 private:	// Disabled copy constructor and operator=
@@ -410,6 +425,13 @@ private:	// Disabled copy constructor and operator=
     QPainter( const QPainter & );
     QPainter &operator=( const QPainter & );
 #endif
+
+    enum TransformationCodes {
+	TxNone      = 0,		// transformation codes
+	TxTranslate = 1,		// copy in qpainter_*.cpp
+	TxScale     = 2,
+	TxRotShear  = 3
+    };
 };
 
 
@@ -671,6 +693,11 @@ inline void QPainter::drawText( int x, int y, int w, int h, int tf,
     drawText( r, tf, str, len, br, i );
 }
 
+inline void QPainter::drawTextItem( const QPoint& p, const QTextItem &ti, int textflags )
+{
+    drawTextItem( p.x(), p.y(), ti, textflags );
+}
+
 inline QRect QPainter::boundingRect( int x, int y, int w, int h, int tf,
 				     const QString& str, int len, QTextParag **i )
 {
