@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qstring.h   3.2.1   edited May 13 09:08 $
+** $Id: qt/qstring.h   3.3.0   edited Nov 7 12:08 $
 **
 ** Definition of the QString class, and related Unicode functions.
 **
@@ -621,11 +621,7 @@ public:
 
     QString    &operator+=( const QString &str );
 #ifndef QT_NO_CAST_ASCII
-#if defined(Q_STRICT_INLINING_RULES)
-    inline QString &operator+=( const QByteArray &str );
-#else
     QString    &operator+=( const QByteArray &str );
-#endif
     QString    &operator+=( const char *str );
 #endif
 #ifndef QT_NO_STL
@@ -913,6 +909,14 @@ inline QString &QString::prepend( const QByteArray & s )
 { return insert(0,s); }
 #endif
 
+#ifndef QT_NO_CAST_ASCII
+inline QString &QString::operator+=( const QByteArray &s )
+{
+    int pos = s.find( 0 );
+    return operatorPlusEqHelper( s, pos==-1 ? s.size() : pos );
+}
+#endif
+
 inline QString &QString::append( const QString & s )
 { return operator+=(s); }
 
@@ -930,14 +934,6 @@ inline QString &QString::append( QChar c )
 inline QString &QString::append( char c )
 { return operator+=(c); }
 
-#ifndef QT_NO_CAST_ASCII
-inline QString &QString::operator+=( const QByteArray &s )
-{
-    int pos = s.find( 0 );
-    return operatorPlusEqHelper( s, pos==-1 ? s.size() : pos );
-}
-#endif
-
 #ifndef QT_NO_STL
 inline QString &QString::operator=( const std::string& str )
 { return operator=(str.c_str()); }
@@ -1083,6 +1079,20 @@ Q_EXPORT inline const QString operator+( char c1, const QString &s2 )
     return tmp;
 }
 
+#ifndef QT_NO_STL
+Q_EXPORT inline const QString operator+(const QString& s1, const std::string& s2)
+{
+    return s1 + QString(s2);
+}
+
+Q_EXPORT inline const QString operator+(const std::string& s1, const QString& s2)
+{
+    QString tmp(s2);
+    return QString(tmp.prepend(s1));
+}
+#endif
+
+
 #if defined(Q_OS_WIN32)
 extern Q_EXPORT QString qt_winQString(void*);
 extern Q_EXPORT const void* qt_winTchar(const QString& str, bool addnul);
