@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qtextedit.h   3.2.1   edited May 19 15:03 $
+** $Id: qt/qtextedit.h   3.3.0   edited Jan 12 16:06 $
 **
 ** Definition of the QTextEdit class
 **
@@ -100,10 +100,6 @@ public:
 	search.line = search.index = 0;
 	tags = lastTag = 0;
     }
-    ~QTextEditOptimPrivate()
-    {
-	clearTags();
-    }
     void clearTags()
     {
 	Tag * itr = tags;
@@ -115,6 +111,10 @@ public:
 	tags = lastTag = 0;
 	tagIndex.clear();
     }
+    ~QTextEditOptimPrivate()
+    {
+	clearTags();
+    }
     int len;
     int numLines;
     int maxLineWidth;
@@ -301,6 +301,7 @@ public:
 
     void setAutoFormatting( uint features );
     uint autoFormatting() const;
+    QSyntaxHighlighter *syntaxHighlighter() const;
 
 public slots:
     void setEnabled( bool );
@@ -395,7 +396,7 @@ public slots:
     void setMaxLogLines( int numLines );
     int maxLogLines();
 #endif
-    
+
 signals:
     void textChanged();
     void selectionChanged();
@@ -543,6 +544,7 @@ private:
     QTextEditOptimPrivate::Tag * optimAppendTag( int index, const QString & tag );
     QTextEditOptimPrivate::Tag * optimInsertTag( int line, int index, const QString & tag );
     void optimCheckLimit( const QString& str );
+    bool optimHasBoldMetrics( int line );
 
 private slots:
     void optimDoAutoScroll();
